@@ -103,6 +103,8 @@ _TESTED_OS_VERSIONS = [
     ("11", "6"),
     ("12", "0"),
     ("12", "1"),
+    ("12", "2"),
+    ("12", "3"),
 ]
 
 # Photos 5 has persons who are empty string if unidentified face
@@ -231,10 +233,6 @@ DEFAULT_ORIGINAL_SUFFIX = ""
 # Default suffix to add to preview images
 DEFAULT_PREVIEW_SUFFIX = "_preview"
 
-# Colors for print CLI messages
-CLI_COLOR_ERROR = "red"
-CLI_COLOR_WARNING = "yellow"
-
 # Bit masks for --sidecar
 SIDECAR_JSON = 0x1
 SIDECAR_EXIFTOOL = 0x2
@@ -259,6 +257,7 @@ EXTENDED_ATTRIBUTE_NAMES = [
 ]
 EXTENDED_ATTRIBUTE_NAMES_QUOTED = [f"'{x}'" for x in EXTENDED_ATTRIBUTE_NAMES]
 
+
 # name of export DB
 OSXPHOTOS_EXPORT_DB = ".osxphotos_export.db"
 
