@@ -69,6 +69,8 @@ def unescape_str(s):
     """unescape an HTML string returned by exiftool -E"""
     if type(s) != str:
         return s
+    # avoid " in values which result in json.loads() throwing an exception, #636
+    s = s.replace("&quot;", '\\"')
     return html.unescape(s)
 
 
@@ -105,7 +107,8 @@ class _ExifToolProc:
 
     def __init__(self, exiftool=None):
         """construct _ExifToolProc singleton object or return instance of already created object
-        exiftool: optional path to exiftool binary (if not provided, will search path to find it)"""
+        exiftool: optional path to exiftool binary (if not provided, will search path to find it)
+        """
 
         if hasattr(self, "_process_running") and self._process_running:
             # already running
@@ -115,7 +118,6 @@ class _ExifToolProc:
                     f"ignoring exiftool={exiftool}"
                 )
             return
-
         self._process_running = False
         self._exiftool = exiftool or get_exiftool_path()
         self._start_proc()
@@ -147,6 +149,9 @@ class _ExifToolProc:
             return
 
         # open exiftool process
+        # make sure /usr/bin at start of path so exiftool can find xattr (see #636)
+        env = os.environ.copy()
+        env["PATH"] = f'/usr/bin/:{env["PATH"]}'
         self._process = subprocess.Popen(
             [
                 self._exiftool,
@@ -163,6 +168,7 @@ class _ExifToolProc:
             stdin=subprocess.PIPE,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
+            env=env,
         )
         self._process_running = True
 
@@ -362,6 +368,7 @@ class ExifTool:
         error = "" if error == b"" else error.decode("utf-8")
         self.warning = warning
         self.error = error
+
         return output[:-EXIFTOOL_STAYOPEN_EOF_LEN], warning, error
 
     @property
@@ -393,6 +400,7 @@ class ExifTool:
         except Exception as e:
             # will fail with some commands, e.g --ext AVI which produces
             # 'No file with specified extension' instead of json
+            logging.warning(f"error loading json returned by exiftool: {e} {json_str}")
             return dict()
         exifdict = exifdict[0]
         if not tag_groups:
