@@ -33,7 +33,7 @@ from ._constants import (
 from ._version import __version__
 from .datetime_utils import datetime_tz_to_utc
 from .exiftool import ExifTool, exiftool_can_write
-from .export_db import ExportDB_ABC, ExportDBNoOp
+from .export_db import ExportDB, ExportDBTemp
 from .fileutil import FileUtil
 from .photokit import (
     PHOTOS_VERSION_CURRENT,
@@ -81,8 +81,10 @@ class ExportOptions:
         exiftool_flags (list of str): optional list of flags to pass to exiftool when using exiftool option, e.g ["-m", "-F"]
         exiftool: (bool, default = False): if True, will use exiftool to write metadata to export file
         export_as_hardlink: (bool, default=False): if True, will hardlink files instead of copying them
-        export_db: (ExportDB_ABC): instance of a class that conforms to ExportDB_ABC with methods for getting/setting data related to exported files to compare update state
+        export_db: (ExportDB): instance of a class that conforms to ExportDB with methods for getting/setting data related to exported files to compare update state
+        face_regions: (bool, default=True): if True, will export face regions
         fileutil: (FileUtilABC): class that conforms to FileUtilABC with various file utilities
+        force_update: (bool, default=False): if True, will export photo if any metadata has changed but export otherwise would not be triggered (e.g. metadata changed but not using exiftool)
         ignore_date_modified (bool): for use with sidecar and exiftool; if True, sets EXIF:ModifyDate to EXIF:DateTimeOriginal even if date_modified is set
         ignore_signature (bool, default=False): ignore file signature when used with update (look only at filename)
         increment (bool, default=True): if True, will increment file name until a non-existant name is found if overwrite=False and increment=False, export will fail if destination file already exists
@@ -126,8 +128,10 @@ class ExportOptions:
     exiftool_flags: Optional[List] = None
     exiftool: bool = False
     export_as_hardlink: bool = False
-    export_db: Optional[ExportDB_ABC] = None
+    export_db: Optional[ExportDB] = None
+    face_regions: bool = True
     fileutil: Optional[FileUtil] = None
+    force_update: bool = False
     ignore_date_modified: bool = False
     ignore_signature: bool = False
     increment: bool = True
@@ -160,6 +164,12 @@ class ExportOptions:
     def asdict(self):
         return asdict(self)
 
+    @property
+    def bit_flags(self):
+        """Return bit flags representing options that affect export"""
+        # currently only exiftool makes a difference
+        return self.exiftool << 1
+
 
 class StagedFiles:
     """Represents files staged for export"""
@@ -399,8 +409,8 @@ class PhotoExporter:
                 "Cannot use export_as_hardlink with download_missing or use_photos_export"
             )
 
-        # when called from export(), won't get an export_db, so use no-op version
-        options.export_db = options.export_db or ExportDBNoOp()
+        # when called from export(), won't get an export_db, so use temp version
+        options.export_db = options.export_db or ExportDBTemp()
 
         # ensure there's a FileUtil class to use
         options.fileutil = options.fileutil or FileUtil
@@ -439,6 +449,7 @@ class PhotoExporter:
 
         # get the right destination path depending on options.update, etc.
         dest = self._get_dest_path(src, dest, options)
+
         self._render_options.filepath = str(dest)
         all_results = ExportResults()
 
@@ -449,91 +460,116 @@ class PhotoExporter:
                 dest,
                 options=options,
             )
+        else:
+            verbose(
+                f"Skipping missing {'edited' if options.edited else 'original'} photo {self.photo.original_filename} ({self.photo.uuid})"
+            )
+            all_results.missing.append(dest)
 
         # copy live photo associated .mov if requested
-        if (
-            export_original
-            and options.live_photo
-            and self.photo.live_photo
-            and staged_files.original_live
-        ):
+        if export_original and options.live_photo and self.photo.live_photo:
             live_name = dest.parent / f"{dest.stem}.mov"
-            src_live = staged_files.original_live
-            all_results += self._export_photo(
-                src_live,
-                live_name,
-                # don't try to convert the live photo
-                options=dataclasses.replace(options, convert_to_jpeg=False),
-            )
+            if staged_files.original_live:
+                src_live = staged_files.original_live
+                all_results += self._export_photo(
+                    src_live,
+                    live_name,
+                    # don't try to convert the live photo
+                    options=dataclasses.replace(options, convert_to_jpeg=False),
+                )
+            else:
+                verbose(
+                    f"Skipping missing live photo for {self.photo.original_filename} ({self.photo.uuid})"
+                )
+                all_results.missing.append(live_name)
 
-        if (
-            export_edited
-            and options.live_photo
-            and self.photo.live_photo
-            and staged_files.edited_live
-        ):
+        if export_edited and options.live_photo and self.photo.live_photo:
             live_name = dest.parent / f"{dest.stem}.mov"
-            src_live = staged_files.edited_live
-            all_results += self._export_photo(
-                src_live,
-                live_name,
-                # don't try to convert the live photo
-                options=dataclasses.replace(options, convert_to_jpeg=False),
-            )
+            if staged_files.edited_live:
+                src_live = staged_files.edited_live
+                all_results += self._export_photo(
+                    src_live,
+                    live_name,
+                    # don't try to convert the live photo
+                    options=dataclasses.replace(options, convert_to_jpeg=False),
+                )
+            else:
+                verbose(
+                    f"Skipping missing edited live photo for {self.photo.original_filename} ({self.photo.uuid})"
+                )
+                all_results.missing.append(live_name)
 
         # copy associated RAW image if requested
-        if options.raw_photo and self.photo.has_raw and staged_files.raw:
-            raw_path = pathlib.Path(staged_files.raw)
-            raw_ext = raw_path.suffix
-            raw_name = dest.parent / f"{dest.stem}{raw_ext}"
-            all_results += self._export_photo(
-                raw_path,
-                raw_name,
-                options=options,
-            )
+        if options.raw_photo and self.photo.has_raw:
+            if staged_files.raw:
+                raw_path = pathlib.Path(staged_files.raw)
+                raw_ext = raw_path.suffix
+                raw_name = dest.parent / f"{dest.stem}{raw_ext}"
+                all_results += self._export_photo(
+                    raw_path,
+                    raw_name,
+                    options=options,
+                )
+            else:
+                # guess at most likely raw name
+                raw_ext = get_preferred_uti_extension(self.photo.uti_raw) or "raw"
+                raw_name = dest.parent / f"{dest.stem}.{raw_ext}"
+                all_results.missing.append(raw_name)
+                verbose(
+                    f"Skipping missing raw photo for {self.photo.original_filename} ({self.photo.uuid})"
+                )
 
         # copy preview image if requested
-        if options.preview and staged_files.preview:
-            # Photos keeps multiple different derivatives and path_derivatives returns list of them
-            # first derivative is the largest so export that one
-            preview_path = pathlib.Path(staged_files.preview)
-            preview_ext = preview_path.suffix
-            preview_name = (
-                dest.parent / f"{dest.stem}{options.preview_suffix}{preview_ext}"
-            )
-            # if original is missing, the filename won't have been incremented so
-            # need to check here to make sure there aren't duplicate preview files in
-            # the export directory
-            preview_name = (
-                preview_name
-                if options.overwrite or options.update
-                else pathlib.Path(increment_filename(preview_name))
-            )
-            all_results += self._export_photo(
-                preview_path,
-                preview_name,
-                options=options,
-            )
+        if options.preview:
+            if staged_files.preview:
+                # Photos keeps multiple different derivatives and path_derivatives returns list of them
+                # first derivative is the largest so export that one
+                preview_path = pathlib.Path(staged_files.preview)
+                preview_ext = preview_path.suffix
+                preview_name = (
+                    dest.parent / f"{dest.stem}{options.preview_suffix}{preview_ext}"
+                )
+                # if original is missing, the filename won't have been incremented so
+                # need to check here to make sure there aren't duplicate preview files in
+                # the export directory
+                preview_name = (
+                    preview_name
+                    if any([options.overwrite, options.update, options.force_update])
+                    else pathlib.Path(increment_filename(preview_name))
+                )
+                all_results += self._export_photo(
+                    preview_path,
+                    preview_name,
+                    options=options,
+                )
+            else:
+                # don't know what actual preview suffix would be but most likely jpeg
+                preview_name = dest.parent / f"{dest.stem}{options.preview_suffix}.jpeg"
+                all_results.missing.append(preview_name)
+                verbose(
+                    f"Skipping missing preview photo for {self.photo.original_filename} ({self.photo.uuid})"
+                )
 
         all_results += self._write_sidecar_files(dest=dest, options=options)
 
-        if options.touch_file:
-            all_results += self._touch_files(all_results, options)
-
         return all_results
 
-    def _touch_files(
-        self, results: ExportResults, options: ExportOptions
-    ) -> ExportResults:
-        """touch file date/time to match photo creation date/time"""
+    def _touch_files(self, touch_files: List, options: ExportOptions) -> ExportResults:
+        """touch file date/time to match photo creation date/time; only touches files if needed"""
         fileutil = options.fileutil
-        touch_files = set(results.to_touch)
-        touch_results = ExportResults()
-        for touch_file in touch_files:
+        touch_results = []
+        for touch_file in set(touch_files):
             ts = int(self.photo.date.timestamp())
-            fileutil.utime(touch_file, (ts, ts))
-            touch_results.touched.append(touch_file)
-        return touch_results
+            try:
+                stat = os.stat(touch_file)
+                if stat.st_mtime != ts:
+                    fileutil.utime(touch_file, (ts, ts))
+                    touch_results.append(touch_file)
+            except FileNotFoundError as e:
+                # ignore errors if in dry_run as file may not be present
+                if not options.dry_run:
+                    raise e from e
+        return ExportResults(touched=touch_results)
 
     def _get_edited_filename(self, original_filename):
         """Return the filename for the exported edited photo
@@ -565,7 +601,7 @@ class PhotoExporter:
 
         # if overwrite==False and #increment==False, export should fail if file exists
         if dest.exists() and not any(
-            [options.increment, options.update, options.overwrite]
+            [options.increment, options.update, options.force_update, options.overwrite]
         ):
             raise FileExistsError(
                 f"destination exists ({dest}); overwrite={options.overwrite}, increment={options.increment}"
@@ -577,24 +613,16 @@ class PhotoExporter:
         # e.g. exporting sidecar for file1.png and file1.jpeg
         # if file1.png exists and exporting file1.jpeg,
         # dest will be file1 (1).jpeg even though file1.jpeg doesn't exist to prevent sidecar collision
-        if options.increment and not options.update and not options.overwrite:
+        if options.increment and not any(
+            [options.update, options.force_update, options.overwrite]
+        ):
             return pathlib.Path(increment_filename(dest))
 
-        # if update and file exists, need to check to see if it's the write file by checking export db
-        if options.update and dest.exists() and src:
+        # if update and file exists, need to check to see if it's the right file by checking export db
+        if (options.update or options.force_update) and dest.exists() and src:
             export_db = options.export_db
-            fileutil = options.fileutil
             # destination exists, check to see if destination is the right UUID
             dest_uuid = export_db.get_uuid_for_file(dest)
-            if dest_uuid is None and fileutil.cmp(src, dest):
-                # might be exporting into a pre-ExportDB folder or the DB got deleted
-                dest_uuid = self.photo.uuid
-                export_db.set_data(
-                    filename=dest,
-                    uuid=self.photo.uuid,
-                    orig_stat=fileutil.file_sig(dest),
-                    info_json=self.photo.json(),
-                )
             if dest_uuid != self.photo.uuid:
                 # not the right file, find the right one
                 # find files that match "dest_name (*.ext" (e.g. "dest_name (1).jpg", "dest_name (2).jpg)", ...)
@@ -609,16 +637,6 @@ class PhotoExporter:
                     if dest_uuid == self.photo.uuid:
                         dest = pathlib.Path(file_)
                         break
-                    elif dest_uuid is None and fileutil.cmp(src, file_):
-                        # files match, update the UUID
-                        dest = pathlib.Path(file_)
-                        export_db.set_data(
-                            filename=dest,
-                            uuid=self.photo.uuid,
-                            orig_stat=fileutil.file_sig(dest),
-                            info_json=self.photo.json(),
-                        )
-                        break
                 else:
                     # increment the destination file
                     dest = pathlib.Path(increment_filename(dest))
@@ -626,6 +644,57 @@ class PhotoExporter:
         # either dest was updated in the if clause above or not updated at all
         return dest
 
+    def _should_update_photo(
+        self, src: pathlib.Path, dest: pathlib.Path, options: ExportOptions
+    ) -> bool:
+        """Return True if photo should be updated, else False"""
+        export_db = options.export_db
+        fileutil = options.fileutil
+
+        file_record = export_db.get_file_record(dest)
+
+        if not file_record:
+            # photo doesn't exist in database, should update
+            return True
+
+        if options.export_as_hardlink and not dest.samefile(src):
+            # different files, should update
+            return True
+
+        if not options.export_as_hardlink and dest.samefile(src):
+            # same file but not exporting as hardlink, should update
+            return True
+
+        if not options.ignore_signature and not fileutil.cmp_file_sig(
+            dest, file_record.dest_sig
+        ):
+            # destination file doesn't match what was last exported
+            return True
+
+        if file_record.export_options != options.bit_flags:
+            # exporting with different set of options (e.g. exiftool), should update
+            # need to check this before exiftool in case exiftool options are different
+            # and export database is missing; this will always be True if database is missing
+            # as it'll be None and bit_flags will be an int
+            return True
+
+        if options.exiftool:
+            current_exifdata = self._exiftool_json_sidecar(options=options)
+            return current_exifdata != file_record.exifdata
+
+        if options.edited and not fileutil.cmp_file_sig(src, file_record.src_sig):
+            # edited file in Photos doesn't match what was last exported
+            return True
+
+        if options.force_update:
+            current_digest = hexdigest(self.photo.json())
+            if current_digest != file_record.digest:
+                # metadata in Photos changed, force update
+                return True
+
+        # photo should not be updated
+        return False
+
     def _stage_photos_for_export(self, options: ExportOptions) -> StagedFiles:
         """Stages photos for export
 
@@ -711,7 +780,7 @@ class PhotoExporter:
         # export live_photo .mov file?
         live_photo = bool(options.live_photo and self.photo.live_photo)
 
-        overwrite = options.overwrite or options.update
+        overwrite = any([options.overwrite, options.update, options.force_update])
 
         # figure out which photo version to request
         if options.edited or self.photo.shared:
@@ -819,7 +888,7 @@ class PhotoExporter:
 
         # export live_photo .mov file?
         live_photo = bool(options.live_photo and self.photo.live_photo)
-        overwrite = options.overwrite or options.update
+        overwrite = any([options.overwrite, options.update, options.force_update])
         edited_version = options.edited or self.photo.shared
         # shared photos (in shared albums) show up as not having adjustments (not edited)
         # but Photos is unable to export the "original" as only a jpeg copy is shared in iCloud
@@ -959,11 +1028,8 @@ class PhotoExporter:
         update_updated_files = []
         update_new_files = []
         update_skipped_files = []  # skip files that are already up to date
-        touched_files = []
         converted_to_jpeg_files = []
         exif_results = ExportResults()
-        converted_stat = None
-        edited_stat = None
 
         dest_str = str(dest)
         dest_exists = dest.exists()
@@ -971,95 +1037,29 @@ class PhotoExporter:
         fileutil = options.fileutil
         export_db = options.export_db
 
-        if options.update:  # updating
-            cmp_touch, cmp_orig = False, False
+        if options.update or options.force_update:  # updating
             if dest_exists:
-                # update, destination exists, but we might not need to replace it...
-                if options.ignore_signature:
-                    cmp_orig = True
-                    cmp_touch = fileutil.cmp(
-                        src, dest, mtime1=int(self.photo.date.timestamp())
-                    )
-                elif options.exiftool:
-                    sig_exif = export_db.get_stat_exif_for_file(dest_str)
-                    cmp_orig = fileutil.cmp_file_sig(dest_str, sig_exif)
-                    sig_exif = (
-                        sig_exif[0],
-                        sig_exif[1],
-                        int(self.photo.date.timestamp()),
-                    )
-                    cmp_touch = fileutil.cmp_file_sig(dest_str, sig_exif)
-                elif options.convert_to_jpeg:
-                    sig_converted = export_db.get_stat_converted_for_file(dest_str)
-                    cmp_orig = fileutil.cmp_file_sig(dest_str, sig_converted)
-                    sig_converted = (
-                        sig_converted[0],
-                        sig_converted[1],
-                        int(self.photo.date.timestamp()),
-                    )
-                    cmp_touch = fileutil.cmp_file_sig(dest_str, sig_converted)
-                else:
-                    cmp_orig = fileutil.cmp(src, dest)
-                    cmp_touch = fileutil.cmp(
-                        src, dest, mtime1=int(self.photo.date.timestamp())
-                    )
-
-                sig_cmp = cmp_touch if options.touch_file else cmp_orig
-
-                if options.edited:
-                    # requested edited version of photo
-                    # need to see if edited version in Photos library has changed
-                    # (e.g. it's been edited again)
-                    sig_edited = export_db.get_stat_edited_for_file(dest_str)
-                    cmp_edited = (
-                        fileutil.cmp_file_sig(src, sig_edited)
-                        if sig_edited != (None, None, None)
-                        else False
-                    )
-                    sig_cmp = sig_cmp and cmp_edited
-
-                if (options.export_as_hardlink and dest.samefile(src)) or (
-                    not options.export_as_hardlink
-                    and not dest.samefile(src)
-                    and sig_cmp
-                ):
-                    # destination exists and signatures match, skip it
-                    update_skipped_files.append(dest_str)
-                elif options.touch_file and cmp_orig and not cmp_touch:
-                    # destination exists, signature matches original but does not match expected touch time
-                    # skip exporting but update touch time
-                    update_skipped_files.append(dest_str)
-                    touched_files.append(dest_str)
-                elif not options.touch_file and cmp_touch and not cmp_orig:
-                    # destination exists, signature matches expected touch but not original
-                    # user likely exported with touch_file and is now exporting without touch_file
-                    # don't update the file because it's same but leave touch time
-                    update_skipped_files.append(dest_str)
-                else:
-                    # destination exists but is different
+                if self._should_update_photo(src, dest, options):
                     update_updated_files.append(dest_str)
-                    if options.touch_file:
-                        touched_files.append(dest_str)
+                else:
+                    update_skipped_files.append(dest_str)
             else:
                 # update, destination doesn't exist (new file)
                 update_new_files.append(dest_str)
-                if options.touch_file:
-                    touched_files.append(dest_str)
         else:
             # not update, export the file
             exported_files.append(dest_str)
-            if options.touch_file:
-                sig = fileutil.file_sig(src)
-                sig = (sig[0], sig[1], int(self.photo.date.timestamp()))
-                if not fileutil.cmp_file_sig(src, sig):
-                    touched_files.append(dest_str)
 
-        if not update_skipped_files:
-            # have file to export
-            edited_stat = (
-                fileutil.file_sig(src) if options.edited else (None, None, None)
+        export_files = update_new_files + update_updated_files + exported_files
+        for export_dest in export_files:
+            # set src_sig before any modifications by convert_to_jpeg or exiftool
+            export_record = export_db.create_or_get_file_record(
+                export_dest, self.photo.uuid
             )
-            if dest_exists and (options.update or options.overwrite):
+            export_record.src_sig = fileutil.file_sig(src)
+            if dest_exists and any(
+                [options.overwrite, options.update, options.force_update]
+            ):
                 # need to remove the destination first
                 try:
                     fileutil.unlink(dest)
@@ -1086,7 +1086,6 @@ class PhotoExporter:
                         src, tmp_file, compression_quality=options.jpeg_quality
                     )
                     src = tmp_file
-                    converted_stat = fileutil.file_sig(tmp_file)
                     converted_to_jpeg_files.append(dest_str)
 
                 if options.exiftool:
@@ -1102,16 +1101,7 @@ class PhotoExporter:
                         f"Error copying file {src} to {dest_str}: {e} ({lineno(__file__)})"
                     ) from e
 
-        export_db.set_data(
-            filename=dest_str,
-            uuid=self.photo.uuid,
-            orig_stat=fileutil.file_sig(dest_str),
-            converted_stat=converted_stat,
-            edited_stat=edited_stat,
-            info_json=self.photo.json(),
-        )
-
-        return ExportResults(
+        results = ExportResults(
             converted_to_jpeg=converted_to_jpeg_files,
             error=exif_results.error,
             exif_updated=exif_results.exif_updated,
@@ -1120,10 +1110,34 @@ class PhotoExporter:
             exported=exported_files + update_new_files + update_updated_files,
             new=update_new_files,
             skipped=update_skipped_files,
-            to_touch=touched_files,
             updated=update_updated_files,
         )
 
+        # touch files if needed
+        if options.touch_file:
+            results += self._touch_files(
+                exported_files
+                + update_new_files
+                + update_updated_files
+                + update_skipped_files,
+                options,
+            )
+
+        # set data in the database
+        with export_db.create_or_get_file_record(dest_str, self.photo.uuid) as rec:
+            photoinfo = self.photo.json()
+            rec.photoinfo = photoinfo
+            rec.export_options = options.bit_flags
+            # don't set src_sig as that is set above before any modifications by convert_to_jpeg or exiftool
+            if not options.ignore_signature:
+                rec.dest_sig = fileutil.file_sig(dest)
+            if options.exiftool:
+                rec.exifdata = self._exiftool_json_sidecar(options)
+            if options.force_update:
+                rec.digest = hexdigest(photoinfo)
+
+        return results
+
     def _write_sidecar_files(
         self,
         dest: pathlib.Path,
@@ -1204,16 +1218,21 @@ class PhotoExporter:
             sidecar_type = data[4]
 
             sidecar_digest = hexdigest(sidecar_str)
-            old_sidecar_digest, sidecar_sig = export_db.get_sidecar_for_file(
-                sidecar_filename
+            sidecar_record = export_db.create_or_get_file_record(
+                sidecar_filename, self.photo.uuid
             )
             write_sidecar = (
-                not options.update
-                or (options.update and not sidecar_filename.exists())
+                not (options.update or options.force_update)
                 or (
-                    options.update
-                    and (sidecar_digest != old_sidecar_digest)
-                    or not fileutil.cmp_file_sig(sidecar_filename, sidecar_sig)
+                    (options.update or options.force_update)
+                    and not sidecar_filename.exists()
+                )
+                or (
+                    (options.update or options.force_update)
+                    and (sidecar_digest != sidecar_record.digest)
+                    or not fileutil.cmp_file_sig(
+                        sidecar_filename, sidecar_record.dest_sig
+                    )
                 )
             )
             if write_sidecar:
@@ -1221,16 +1240,13 @@ class PhotoExporter:
                 files_written.append(str(sidecar_filename))
                 if not options.dry_run:
                     self._write_sidecar(sidecar_filename, sidecar_str)
-                    export_db.set_sidecar_for_file(
-                        sidecar_filename,
-                        sidecar_digest,
-                        fileutil.file_sig(sidecar_filename),
-                    )
+                    sidecar_record.digest = sidecar_digest
+                    sidecar_record.dest_sig = fileutil.file_sig(sidecar_filename)
             else:
                 verbose(f"Skipped up to date {sidecar_type} sidecar {sidecar_filename}")
                 files_skipped.append(str(sidecar_filename))
 
-        return ExportResults(
+        results = ExportResults(
             sidecar_json_written=sidecar_json_files_written,
             sidecar_json_skipped=sidecar_json_files_skipped,
             sidecar_exiftool_written=sidecar_exiftool_files_written,
@@ -1239,6 +1255,26 @@ class PhotoExporter:
             sidecar_xmp_skipped=sidecar_xmp_files_skipped,
         )
 
+        if options.touch_file:
+            all_sidecars = (
+                sidecar_json_files_written
+                + sidecar_exiftool_files_written
+                + sidecar_xmp_files_written
+                + sidecar_json_files_skipped
+                + sidecar_exiftool_files_skipped
+                + sidecar_xmp_files_skipped
+            )
+            results += self._touch_files(all_sidecars, options)
+
+            # update destination signatures in database
+            for sidecar_filename in all_sidecars:
+                sidecar_record = export_db.create_or_get_file_record(
+                    sidecar_filename, self.photo.uuid
+                )
+                sidecar_record.dest_sig = fileutil.file_sig(sidecar_filename)
+
+        return results
+
     def _write_exif_metadata_to_file(
         self,
         src,
@@ -1253,10 +1289,7 @@ class PhotoExporter:
         local machine prior to being copied to the export destination which may be on a
         network drive or other slower external storage."""
 
-        export_db = options.export_db
-        fileutil = options.fileutil
         verbose = options.verbose or self._verbose
-
         exiftool_results = ExportResults()
 
         # don't try to write if unsupported file type for exiftool
@@ -1267,20 +1300,36 @@ class PhotoExporter:
                     f"Unsupported file type for exiftool, skipping exiftool for {dest}",
                 )
             )
+            # set file signature so the file doesn't get re-exported with --update
             return exiftool_results
 
         # determine if we need to write the exif metadata
         # if we are not updating, we always write
         # else, need to check the database to determine if we need to write
-        run_exiftool = not options.update
-        if options.update:
+        verbose(f"Writing metadata with exiftool for {pathlib.Path(dest).name}")
+        if not options.dry_run:
+            warning_, error_ = self._write_exif_data(src, options=options)
+            if warning_:
+                exiftool_results.exiftool_warning.append((dest, warning_))
+            if error_:
+                exiftool_results.exiftool_error.append((dest, error_))
+                exiftool_results.error.append((dest, error_))
+
+        exiftool_results.exif_updated.append(dest)
+        exiftool_results.to_touch.append(dest)
+        return exiftool_results
+
+    def _should_run_exiftool(self, dest, options: ExportOptions) -> bool:
+        """Return True if exiftool should be run to update metadata"""
+        run_exiftool = not options.update and not options.force_update
+        if options.update or options.force_update:
             files_are_different = False
-            old_data = export_db.get_exifdata_for_file(dest)
+            exif_record = options.export_db.get_file_record(dest)
+            old_data = exif_record.exifdata if exif_record else None
             if old_data is not None:
                 old_data = json.loads(old_data)[0]
-                current_data = json.loads(self._exiftool_json_sidecar(options=options))[
-                    0
-                ]
+                current_data = json.loads(self._exiftool_json_sidecar(options=options))
+                current_data = current_data[0]
                 if old_data != current_data:
                     files_are_different = True
 
@@ -1288,30 +1337,7 @@ class PhotoExporter:
                 # didn't have old data, assume we need to write it
                 # or files were different
                 run_exiftool = True
-            else:
-                verbose(
-                    f"Skipped up to date exiftool metadata for {pathlib.Path(dest).name}"
-                )
-
-        if run_exiftool:
-            verbose(f"Writing metadata with exiftool for {pathlib.Path(dest).name}")
-            if not options.dry_run:
-                warning_, error_ = self._write_exif_data(src, options=options)
-                if warning_:
-                    exiftool_results.exiftool_warning.append((dest, warning_))
-                if error_:
-                    exiftool_results.exiftool_error.append((dest, error_))
-                    exiftool_results.error.append((dest, error_))
-
-            export_db.set_data(
-                dest,
-                uuid=self.photo.uuid,
-                exif_stat=fileutil.file_sig(src),
-                exif_json=self._exiftool_json_sidecar(options=options),
-            )
-            exiftool_results.exif_updated.append(dest)
-            exiftool_results.to_touch.append(dest)
-        return exiftool_results
+        return run_exiftool
 
     def _write_exif_data(self, filepath: str, options: ExportOptions):
         """write exif data to image file at filepath
@@ -1486,6 +1512,9 @@ class PhotoExporter:
             person_list = sorted(list(set(person_list)))
             exif["XMP:PersonInImage"] = person_list.copy()
 
+        if options.face_regions and self.photo.face_info:
+            exif.update(self._get_mwg_face_regions_exiftool())
+
         # if self.favorite():
         #     exif["Rating"] = 5
 
@@ -1568,6 +1597,42 @@ class PhotoExporter:
 
         return exif
 
+    def _get_mwg_face_regions_exiftool(self):
+        """Return a dict with MWG face regions for use by exiftool"""
+        if self.photo.orientation in [5, 6, 7, 8]:
+            w = self.photo.height
+            h = self.photo.width
+        else:
+            w = self.photo.width
+            h = self.photo.height
+        exif = {}
+        exif["XMP:RegionAppliedToDimensionsW"] = w
+        exif["XMP:RegionAppliedToDimensionsH"] = h
+        exif["XMP:RegionAppliedToDimensionsUnit"] = "pixel"
+        exif["XMP:RegionName"] = []
+        exif["XMP:RegionType"] = []
+        exif["XMP:RegionAreaX"] = []
+        exif["XMP:RegionAreaY"] = []
+        exif["XMP:RegionAreaW"] = []
+        exif["XMP:RegionAreaH"] = []
+        exif["XMP:RegionAreaUnit"] = []
+        exif["XMP:RegionPersonDisplayName"] = []
+        # exif["XMP:RegionRectangle"] = []
+        for face in self.photo.face_info:
+            if not face.name:
+                continue
+            area = face.mwg_rs_area
+            exif["XMP:RegionName"].append(face.name)
+            exif["XMP:RegionType"].append("Face")
+            exif["XMP:RegionAreaX"].append(area.x)
+            exif["XMP:RegionAreaY"].append(area.y)
+            exif["XMP:RegionAreaW"].append(area.w)
+            exif["XMP:RegionAreaH"].append(area.h)
+            exif["XMP:RegionAreaUnit"].append("normalized")
+            exif["XMP:RegionPersonDisplayName"].append(face.name)
+            # exif["XMP:RegionRectangle"].append(f"{area.x},{area.y},{area.h},{area.w}")
+        return exif
+
     def _get_exif_keywords(self):
         """returns list of keywords found in the file's exif metadata"""
         keywords = []
