@@ -54,7 +54,7 @@ from .scoreinfo import ScoreInfo
 from .searchinfo import SearchInfo
 from .text_detection import detect_text
 from .uti import get_preferred_uti_extension, get_uti_for_extension
-from .utils import _debug, _get_resource_loc, list_directory
+from .utils import _debug, _get_resource_loc, list_directory, _debug
 
 __all__ = ["PhotoInfo", "PhotoInfoNone"]
 
@@ -588,6 +588,7 @@ class PhotoInfo:
     @property
     def ismissing(self):
         """returns true if photo is missing from disk (which means it's not been downloaded from iCloud)
+
         NOTE:   the photos.db database uses an asynchrounous write-ahead log so changes in Photos
                 do not immediately get written to disk. In particular, I've noticed that downloading
                 an image from the cloud does not force the database to be updated until something else
@@ -1488,7 +1489,8 @@ class PhotoInfo:
         description_template: string; optional template string that will be rendered for use as photo description
         render_options: an optional osxphotos.phototemplate.RenderOptions instance with options to pass to template renderer
 
-        Returns: list of photos exported
+        Returns:
+            list of photos exported
         """
 
         exporter = PhotoExporter(self)
@@ -1728,7 +1730,11 @@ class PhotoInfo:
             if isinstance(o, (datetime.date, datetime.datetime)):
                 return o.isoformat()
 
-        return json.dumps(self.asdict(), sort_keys=True, default=default)
+        dict_data = self.asdict()
+        for k, v in dict_data.items():
+            if v and isinstance(v, (list, tuple)) and not isinstance(v[0], dict):
+                dict_data[k] = sorted(v)
+        return json.dumps(dict_data, sort_keys=True, default=default)
 
     def __eq__(self, other):
         """Compare two PhotoInfo objects for equality"""
