@@ -4,7 +4,7 @@
 import logging
 
 from .._constants import _DB_TABLE_NAMES, _PHOTOS_4_VERSION
-from ..utils import _db_is_locked, _debug, _open_sql_file
+from ..utils import _db_is_locked, _open_sql_file
 from .photosdb_utils import get_db_version
 
 
